@@ -1,5 +1,8 @@
+from ..error import EmbedNotFound
+
+
 class ObjectBase(dict):
-    def __init__(self, data, client=None):
+    def __init__(self, data, client):
         """
         Create a new object from API result data.
         """
@@ -19,6 +22,20 @@ class ObjectBase(dict):
         except (KeyError, TypeError):
             return None
 
+    def get_embedded(self, name: str) -> dict:
+        """
+        Get embedded data by its name.
+
+        :param name: The name of the embedded data.
+        :type name: str
+
+        :raises EmbedNotFound: When no embedded data with the given name exists.
+        """
+        try:
+            return self["_embedded"][name]
+        except KeyError:
+            raise EmbedNotFound(name)
+
     @classmethod
     def get_object_name(cls):
         name = cls.__name__.lower()
@@ -26,4 +43,4 @@ class ObjectBase(dict):
 
     @classmethod
     def get_resource_class(cls, client):
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: no cover
